/* Copyright (c) 2001, Daniel Wexler, All Rights Reserved */
/*
    This file is part of the FB library.

    The FB library is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    The FB library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Foobar; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*
 * $Header
 *
 * $Log: main.c,v $
 * Revision 1.1  2001/05/23 20:55:06  wex
 * Added to repository.
 *
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include <fb.h>

static void usage();


int
main(int argc, char *argv[])
{
    int i, seconds;
    short red[256], grn[256], blu[256];
    
    if (argc == 1) {
        seconds = 10;
    } else if (argc == 2) {
        seconds = atoi(argv[1]);
        if (seconds < 0 || seconds > 1000) {
            usage();
            return EXIT_FAILURE;
        }
    } else {
        usage();
        return EXIT_FAILURE;
    }

    /* Set luts to random values with neighboring values coming
       from different parts of the spectrum.  This allows you to
       see small differences easily. */
    for (i = 0; i < 256; i++) {
        red[i] = drand48() * 64;
        switch (i%4) {
        case 0:                break;
        case 1: red[i] += 192; break;
        case 2: red[i] += 64;  break;
        case 3: red[i] += 128; break;
        }

        grn[i] = red[i];
        blu[i] = red[i];
    }

    if (FB_set_luts(red, grn, blu) != 0) {
        fprintf(stderr, "%s Error: %s\n", argv[0], FB_error_string());
        return EXIT_FAILURE;
    }

    sleep(seconds);
    
    for (i = 0; i < 256; i++) {
        red[i] = i;
        grn[i] = i;
        blu[i] = i;
    }
    
    if (FB_set_luts(red, grn, blu) != 0) {
        fprintf(stderr, "%s Error: %s\n", argv[0], FB_error_string());
        return EXIT_FAILURE;
    }

    return EXIT_SUCCESS;
}

static void
usage(void)
{
    fprintf(stderr, "Usage: fb_flash [seconds]\n");
    fprintf(stderr, "Which: sets the hardware lookup tables to random "
        "values\n");
    fprintf(stderr, "Where: [seconds]   Optional delay time (10)\n");
}
