/* Copyright (c) 2001, Daniel Wexler, All Rights Reserved */
/*
    This file is part of the FB library.

    The FB library is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    The FB library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Foobar; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*
 * $Header: /usr/local/cvsroot/flarg/lib/fb/fb.h,v 1.2 2001/06/06 21:49:42 wex Exp $
 *
 * $Log: fb.h,v $
 * Revision 1.2  2001/06/06 21:49:42  wex
 * Comments.  Include math.h.
 *
 * Revision 1.1  2001/05/23 20:06:28  wex
 * Added to repository.
 *
 *
 */

#ifndef _FB_H_
#define _FB_H_

/*

  The FB library contains routines for setting the hardware frame
  buffer color lookup tables.  This is a useful foundation for writing
  a more complete color callibration system which would include
  measuring the response curve of your monitor using a photometer and
  constructing lookup tables that mimic a desired target response,
  such as a particular film stock.

  These routines currently work under Linux NVidia GeForce card,
  or with an HP FX/5 card, or on an SGI machine running IRIX.
  To get the routines to compile for those platforms, make sure
  to set the proper define in the Makefile.

  To use these routines, construct a set of three lookup tables
  for red, green and blue and call the function, FB_set_luts().
  This will change the colors used in all windows on the screen.

  Note: when using the special YUV X extensions for the NVidia
  card, the LUTs are bypassed, which means these routines will
  have no affect.  This is really too bad since these extensions
  are really useful for displaying Jpeg compressed images since
  you can avoid the YUV->RGB conversion.
  
*/

/* error return codes */
#define FB_ERR_NONE             0
#define FB_ERR_PERMISSION       1
#define FB_ERR_GAMMA_RANGE      2

/* contains the error code if a function returns an error */
extern int FB_errno;

/* returns a user readable string for error messages */
char *FB_error_string(void);


/* returns -1 on failure, use the range 0-256 even though these are shorts */ 
int FB_set_luts(short red[256], short grn[256], short blu[256]);

/* returns -1 on failure, sets the luts to the specified gamma curve */
int FB_set_gamma(double gamma);

#endif /* _FB_H_ */
