/* Copyright (c) 2001, Daniel Wexler, All Rights Reserved */
/*
    This file is part of the FB library.

    The FB library is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    The FB library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Foobar; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*
 * $Header: /usr/local/cvsroot/flarg/lib/fb/fb_lut.c,v 1.2 2001/06/06 21:49:42 wex Exp $
 *
 * $Log: fb_lut.c,v $
 * Revision 1.2  2001/06/06 21:49:42  wex
 * Comments.  Include math.h.
 *
 * Revision 1.1  2001/05/23 20:06:28  wex
 * Added to repository.
 *
 *
 */

#include "fb.h"

#include <math.h>

#ifdef FB_NVIDIA
#include <sys/io.h>
#define FB_NV_PORT_ADDRESS  0x3C8
#endif



/* Set the hardware lookup tables for NVidia, HP-FX/5, or SGI machines */
int
FB_set_luts(short red[256], short grn[256], short blu[256])
{
#ifdef FB_SGI
    long window;

    foreground();
    noport();
    win = winopen("");
    gammaramp(red, grn, blu);
    gsync();
    gsync();
    winclose();
#endif

#ifdef FB_NVIDIA
    int i;
    
    if (ioperm(FB_NV_PORT_ADDRESS, 2, 1) != 0) {
        FB_errno = FB_ERR_PERMISSION;
        return -1;
    }

    for (i = 0; i < 256; i++) {
        outb(i, FB_NV_PORT_ADDRESS);
        outb(red[i], FB_NV_PORT_ADDRESS + 1);
        outb(grn[i], FB_NV_PORT_ADDRESS + 1);
        outb(blu[i], FB_NV_PORT_ADDRESS + 1);
    }
#endif

#ifdef FB_HP_FX5
    XHPSetDefaultColorTable(display, window, r, g, b);
#endif

    return 0;
}


/* A convenience function for setting a specific gamma ramp */
int
FB_set_gamma(double gamma)
{
    int i;
    short red[256], grn[256], blu[256];
    
    if (gamma <= 0 || gamma > 1000) {
        FB_errno = FB_ERR_GAMMA_RANGE;
        return -1;
    }

    for (i = 0; i < 256; i++) {
        red[i] = 255.9 * pow(i/256.0, 1/gamma);
        grn[i] = 255.9 * pow(i/256.0, 1/gamma);
        blu[i] = 255.9 * pow(i/256.0, 1/gamma);
    }

    if (FB_set_luts(red, grn, blu) != 0) {
        return -1;
    }

    return 0;
}

